
#ifndef _C13_et633_
#define _C13_et633_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1532_13971(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit633(void);
extern char *(*R1685[])();

#ifdef __cplusplus
}
#endif

#endif
